@@ -169,6 +169,11 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 	row, column := ui.table.GetSelection()
 	selectedItem := ui.table.GetCell(row, column).GetReference().(fs.Item)
 
+	if ui.deleteInBackground {
+		ui.queueForDeletion([]fs.Item{selectedItem}, shouldEmpty)
+		return
+	}
+
 	var action, acting string
 	if shouldEmpty {
 		action = "empty "
@@ -221,8 +226,10 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 
 		ui.app.QueueUpdateDraw(func() {
 			ui.pages.RemovePage(acting)
+			x, y := ui.table.GetOffset()
 			ui.showDir()
 			ui.table.Select(min(row, ui.table.GetRowCount()-1), 0)
+			ui.table.SetOffset(min(x, ui.table.GetRowCount()-1), y)
 		})
 
 		if ui.done != nil {
